PrefabFiles = {
    "g",
    "pencil",
}

Assets = {
    Asset( "IMAGE", "images/saveslot_portraits/g.tex" ),
    Asset( "ATLAS", "images/saveslot_portraits/g.xml" ),

    Asset( "IMAGE", "images/selectscreen_portraits/g.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/g.xml" ),
    
    Asset( "IMAGE", "images/selectscreen_portraits/g_silho.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/g_silho.xml" ),

    Asset( "IMAGE", "bigportraits/g.tex" ),
    Asset( "ATLAS", "bigportraits/g.xml" ),
    
    Asset( "IMAGE", "images/map_icons/g.tex" ),
    Asset( "ATLAS", "images/map_icons/g.xml" ),

    Asset("SOUNDPACKAGE", "sound/g.fev"),
    Asset("SOUND", "sound/g.fsb"),

}

RemapSoundEvent( "dontstarve/characters/g/death_voice", "g/g/death_voice" )
RemapSoundEvent( "dontstarve/characters/g/hurt", "g/g/hurt" )
RemapSoundEvent( "dontstarve/characters/g/talk_LP", "g/g/talk_LP" )


local require = GLOBAL.require
local STRINGS = GLOBAL.STRINGS
local RECIPETABS = GLOBAL.RECIPETABS
local TECH = GLOBAL.TECH
local resolvefilepath = GLOBAL.resolvefilepath

-- The character select screen lines
STRINGS.CHARACTER_TITLES.g = "The Sketch Artist"
STRINGS.CHARACTER_NAMES.g = "G Noe"
STRINGS.CHARACTER_DESCRIPTIONS.g = "*Able to sketch to regain sanity\n*Hits hard and acquires much endurance\n*Not easily scared, though has nyctophobia"
STRINGS.CHARACTER_QUOTES.g = "\"Ya peice'a cunt.\""

STRINGS.NAMES.PENCIL = "Pencil"
STRINGS.RECIPE_DESC.PENCIL = "Useful for passing time."
STRINGS.CHARACTERS.GENERIC.DESCRIBE.PENCIL = "It's a writing stick!"

STRINGS.ACTIONS.PENCILMOD_WRITE = "Sketch"

-- Custom speech strings
STRINGS.CHARACTERS.G = require "speech_g"

table.insert(GLOBAL.CHARACTER_GENDERS.MALE, "g")

AddMinimapAtlas("images/map_icons/g.xml")
AddModCharacter("g")

-- Recipe

local pencil_recipe = Recipe("pencil", { Ingredient("twigs", 2), Ingredient("charcoal", 1) }, RECIPETABS.TOOLS, TECH.SCIENCE_ONE)
pencil_recipe.atlas = resolvefilepath("images/inventoryimages/pencil.xml")

-- Action
local ACTIONS = GLOBAL.ACTIONS
local Action = GLOBAL.Action
local ActionHandler = GLOBAL.ActionHandler

ACTIONS.PENCILMOD_WRITE = Action()
ACTIONS.PENCILMOD_WRITE.str = STRINGS.ACTIONS.PENCILMOD_WRITE
ACTIONS.PENCILMOD_WRITE.id = "PENCILMOD_WRITE"

ACTIONS.PENCILMOD_WRITE.fn = function(act)
    if act.target and act.target:HasTag("pencilmod_writeable") and act.invobject and act.invobject.components.pencilmod_writer then
        return act.invobject.components.pencilmod_writer:DoWrite(act.target, act.doer)
    end
end

AddStategraphActionHandler("wilson", ActionHandler(ACTIONS.PENCILMOD_WRITE, "dolongaction"))

-- Make papyrus writeable
AddPrefabPostInit("papyrus", function(inst)
    inst:AddTag("pencilmod_writeable")
end)


-- Whenever my brethren are touched by me in a harmful way, I start to lose my mind... in a bad way, of course
local function LoseSanity(inst,data)
  if data and data.attacker and data.attacker.components.sanity then
    if inst.components.health:IsDead() then
      data.attacker.components.sanity:DoDelta(-25)
    else
      data.attacker.components.sanity:DoDelta(-10)
    end
  end
end

AddPrefabPostInit("catcoon",function(inst)
    inst:AddTag("companion")
    inst:ListenForEvent("attacked",LoseSanity)
end)

local function LoseSanityLarge(inst,data)
  if data and data.attacker and data.attacker.components.sanity then
    if inst.components.health:IsDead() then
      data.attacker.components.sanity:DoDelta(-200)
    else
      data.attacker.components.sanity:DoDelta(-90)
    end
  end
end

local function LoseSanityMed(inst,data)
  if data and data.attacker and data.attacker.components.sanity then
    if inst.components.health:IsDead() then
      data.attacker.components.sanity:DoDelta(-200)
    else
      data.attacker.components.sanity:DoDelta(-50)
    end
  end
end

AddPrefabPostInit("g", function(inst)
	inst:ListenForEvent("oneat", function(inst, data)
		local food = data and data.food
		if food and (food.prefab == "coconut_cooked") then
			inst.components.sanity:DoDelta(-2)
			inst.components.talker:Say(GLOBAL.GetString(inst.prefab, "ANNOUNCE_EAT", "SPOILED"))
		end
	end)
end)

AddPrefabPostInit("sharkitten",function(inst)
    inst:AddTag("companion")
    inst:ListenForEvent("attacked",LoseSanityLarge)
end)

AddPrefabPostInit("tigershark",function(inst)
    inst:AddTag("companion")
    inst:ListenForEvent("attacked",LoseSanityMed)
end)

local function GdoesNotLike(item,player)
    if player.prefab == "g" then
        return -GLOBAL.TUNING.SANITYAURA_MED
    end
    return 0
end

GLOBAL.G_DISLIKES = {
    shark_gills = true,
    tigereye = true,
    supertelescope = true,
    seasack = true,
    double_umbrellahat = true,
}

for prefab, _ in pairs(GLOBAL.G_DISLIKES) do
    AddPrefabPostInit(prefab, function(inst)
        if not inst.components.sanityaura then
            inst:AddComponent("sanityaura")
        end
        if inst.components.sanityaura.aurafn then
            local oldaurafn = inst.components.sanityaura.aurafn
            inst.components.sanityaura.aurafn = function(...)
                return oldaurafn(...) + GdoesNotLike(...)
            end
        else
            inst.components.sanityaura.aurafn = GdoesNotLike
        end
    end)
end

-- Custom intro, yo

local function ModMaxwellIntro(inst)
    if GLOBAL.GetPlayer().prefab == "g" then
        inst.components.maxwelltalker.speeches.SANDBOX_1 =
        {
            appearsound = "dontstarve/maxwell/disappear",
            voice = "dontstarve/maxwell/talk_LP",
            appearanim = "appear",
            idleanim= "idle",
            dialogpreanim = "dialog_pre",
            dialoganim="dial_loop",
            dialogpostanim = "dialog_pst",
            disappearanim = "disappear",
            disableplayer = true,
            skippable = false,
            {
                string = "Say, pal. You don't look s--",
                wait = 2,
                anim = nil,
                sound = nil,
            },
            {
                string = "What the?",
                wait = 1,
                anim = nil,
                sound = nil,
            },
            {
                string = "I could have sworn I had given the knowledge to Wilson...",
                wait = 3,
                anim = nil,
                sound = nil,
            },
            {
            string = "Well, whatever it is.",
                wait = 1.5,
                anim = nil,
                sound = nil,
                
            },
            {
            string = STRINGS.MAXWELL_SANDBOXINTROS.TWO,
                wait = 3,
                anim = nil,
                sound = nil,
            },
        }
        inst.components.maxwelltalker.speeches.ADVENTURE_1 =
        {
            appearsound = "dontstarve/maxwell/appear_adventure",
            delay = 2,
            voice = "dontstarve/maxwell/talk_LP_world1",
            appearanim = "appear2",
            idleanim= "idle2_loop",
            dialogpreanim = "dialog2_pre",
            dialoganim="dialog2_loop",
            dialogpostanim = "dialog2_pst",
            disappearanim = "disappear2",
            disableplayer = true,
            skippable = true,
            {
                string = "You know, I underestimated you.",
                wait = 2,
                anim = nil,
                sound = nil,
            },
            {
                string = "You seem more intelligent than you look.",
                wait = 2.5,
                anim = nil,
                sound = nil,
            },
            {
                string = "Most probably because of the knowledge I foolishly handed to you.",
                wait = 3,
                anim = nil,
                sound = nil,
            },
            {
                string = "No matter, I'm sure this should stop you in your tracks.",
                wait = 3,
                anim = dialog2_loop,
                sound = nil,
            },
        }
    end
end

AddPrefabPostInit("maxwellintro", ModMaxwellIntro)


-- Sanity penalty on using supertelescope
local function SuperTelescopePostInit(inst)
	local _spell = inst.components.spellcaster.spell
	inst.components.spellcaster.spell = function(inst, target, pos)
		if GLOBAL.GetPlayer().prefab == "g" then
			GLOBAL.GetPlayer().components.sanity:DoDelta(-25)
		end
		return _spell(inst, target, pos)
	end
end
AddPrefabPostInit("supertelescope", SuperTelescopePostInit)

-- Add ability to write on boat
AddStategraphActionHandler("wilsonboating", ActionHandler(ACTIONS.PENCILMOD_WRITE, "dolongaction"))
