local MakePlayerCharacter = require "prefabs/player_common"

local assets = {

		Asset( "ANIM", "anim/player_basic.zip" ),
		Asset( "ANIM", "anim/player_idles_shiver.zip" ),
		Asset( "ANIM", "anim/player_actions.zip" ),
		Asset( "ANIM", "anim/player_actions_axe.zip" ),
		Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
		Asset( "ANIM", "anim/player_actions_shovel.zip" ),
		Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
		Asset( "ANIM", "anim/player_actions_eat.zip" ),
		Asset( "ANIM", "anim/player_actions_item.zip" ),
		Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
		Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
		Asset( "ANIM", "anim/player_actions_fishing.zip" ),
		Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
		Asset( "ANIM", "anim/player_bush_hat.zip" ),
		Asset( "ANIM", "anim/player_attacks.zip" ),
		Asset( "ANIM", "anim/player_idles.zip" ),
		Asset( "ANIM", "anim/player_rebirth.zip" ),
		Asset( "ANIM", "anim/player_jump.zip" ),
		Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
		Asset( "ANIM", "anim/player_teleport.zip" ),
		Asset( "ANIM", "anim/wilson_fx.zip" ),
		Asset( "ANIM", "anim/player_one_man_band.zip" ),
		Asset( "ANIM", "anim/shadow_hands.zip" ),
		Asset( "ANIM", "anim/beard.zip" ),
		Asset( "SOUND", "sound/sfx.fsb" ),
		Asset( "SOUND", "sound/wilson.fsb" ),

		Asset( "ANIM", "anim/g.zip" ),
		Asset( "ANIM", "anim/g_left.zip"),
}

local prefabs = {
	"pencil",
}

local start_inv = {
	"pencil",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
	"papyrus",
}

local function SideAnim(inst)
	--left and right animation should be exactly the same, 
	--except for the parts that should have a left and right version.
	if inst.AnimState:GetCurrentFacing() == FACING_LEFT then
		inst.AnimState:SetBuild("g_left") -- left animation
	elseif inst.AnimState:GetCurrentFacing() == FACING_RIGHT then
		inst.AnimState:SetBuild("g") -- right animation
	end
end

local function SanityRate(inst)
	local delta = 0
	
	local items = inst.components.inventory:FindItems(function(item)
		return G_DISLIKES[item.prefab]
	end)
	
	delta = delta - math.min(TUNING.SANITYAURA_MED * #items, TUNING.SANITYAURA_LARGE)

	-- My penalty for having equipped equipments that are made of Papi
	local equip_delta = 0
	for k, v in pairs(inst.components.inventory.equipslots) do
		if v.prefab == "double_umbrellahat" or v.prefab == "supertelescope" or v.prefab == "seasack" then
			equip_delta = equip_delta - TUNING.SANITYAURA_HUGE
		end
	end
	
	local flame_delta = 0
	if GetClock():IsNight() or GetClock():IsDusk() then
		local x,y,z = inst.Transform:GetWorldPosition()
		local radius = 5
		local hotprefabs = TheSim:FindEntities(x, y, z, radius, {"campfire"}) -- both normal and endo firepits/campfires
		for k,v in pairs(hotprefabs) do
			if v.components.fueled then
				flame_delta = flame_delta + (TUNING.DAPPERNESS_LARGE * (v.components.fueled.sections * .25))--sections are 0-4 so 1 = 25%
			end
		end
	end
	
	return equip_delta + delta + flame_delta
end

local function OnEatCheckForDebuff(inst, food)
	if food then
		if G_DISLIKES[food.prefab] then
			inst.components.sanity:DoDelta(-TUNING.SANITY_HUGE * 3)
		end
	end
end

local fn = function(inst)
	
	inst.soundsname = "g"
	inst.talker_path_override = "g/"

	inst.MiniMapEntity:SetIcon( "g.tex" )
	
	inst.components.health:SetMaxHealth(180)
	inst.components.hunger:SetMax(175)
	inst.components.sanity:SetMax(180)
	
	inst.components.combat.damagemultiplier = 2
	
	inst.components.hunger.hungerrate = 0.8 * TUNING.WILSON_HUNGER_RATE

	inst.components.locomotor.walkspeed = 3.5
	inst.components.locomotor.runspeed = 5.5
	inst:ListenForEvent("locomote", SideAnim)
	
	-- My nyctophobia
	inst.components.sanity.night_drain_mult = 2

	-- My near-dead reaction towards most things
	inst.components.sanity.neg_aura_mult = 0.3
	

	-- I can withstand summer
	inst.components.temperature.overheattemp = 150
	
	-- I'll be more vulnerable in winter
	inst.components.temperature.mintemp = ( 15 )

	inst:AddTag("sharkitten")

	inst.components.sanity.custom_rate_fn = SanityRate

	inst.components.eater:SetOnEatFn(OnEatCheckForDebuff)
end

return MakePlayerCharacter("g", prefabs, assets, fn, start_inv)
